<a id="autonomy.cli.develop"></a>

# autonomy.cli.develop

Develop CLI module.

<a id="autonomy.cli.develop.develop_group"></a>

#### develop`_`group

```python
@click.group(name="develop")
def develop_group() -> None
```

AEA development.

